pub fn render(
env: &Environment,
loader: Option<&(dyn TemplateLoader + Send + Sync)>,
root: &Node,
ctx_stack: &mut CtxStack,
) -> Result<String>Expand description
Renders root to a string using env and ctx_stack.
pub fn render(
env: &Environment,
loader: Option<&(dyn TemplateLoader + Send + Sync)>,
root: &Node,
ctx_stack: &mut CtxStack,
) -> Result<String>Renders root to a string using env and ctx_stack.